@@ -72,6 +72,10 @@ def multiplot(*args, **kwargs):
     g.reset()
 
 def plot(*args, **kwargs):
+    '''
+    *items: The list of plot command;
+    **kwargs: The options that would be set before the plot command.
+    '''
     __gnuplot("plot", *args, **kwargs)
 
 def splot(*args, **kwargs):
@@ -115,6 +119,11 @@ class Gnuplot(object):
         self.close()
 
     def cmd(self, *args):
+        '''
+        *args: all the line that need to pass to gnuplot. It could be a list of
+        lines, or a paragraph; Lines starting with "#" would be omitted. Every
+        line should be a clause that could be executed in gnuplot.
+        '''
         commands = []
         for cmd in args:
             #print StringIO(cmd.strip()).readlines()
@@ -157,8 +166,9 @@ class Gnuplot(object):
 
     def set(self, *args, **kwargs):
         '''
-        kwargs is non-ordered, if there is order requirement, please call set
-        many times in order.
+        *args: options without value
+        *kwargs: options with value. The set and unset commands may optionally
+                 contain an iteration clause, so the arg could be list.
         '''
         for v in args:
             #print('set %s' %(v))
@@ -176,6 +186,9 @@ class Gnuplot(object):
                     self.cmd('set %s %s' %(k, v))
 
     def unset(self, *items):
+        '''
+        *args: options that need to be unset
+        '''
         for item in items:
             self.cmd('unset %s\n' %(item))
 
@@ -183,6 +196,10 @@ class Gnuplot(object):
         self.cmd('reset')
 
     def plot(self, *items, **kwargs):
+        '''
+        *items: The list of plot command;
+        **kwargs: The options that would be set before the plot command.
+        '''
         self.set(**kwargs)
         c = 'plot'
         for item in items:
