@@ -111,6 +111,13 @@ class Gnuplot(gnuplot.Gnuplot):
     """
 
     def plot(self, data, *items, **kwargs):
+        '''
+        data: The data that need to be plotted. It's either the string of list
+        or the Pnadas Dataframe, if it's Pnadas Dataframe it would be converted
+        to string by data.to_csv(sep = ' ')
+        *items: The list of plot command;
+        **kwargs: The options that would be set before the plot command.
+        '''
         self.set(**kwargs)
         c = 'plot'
         for item in items:
